==> primer-react-34.1.0.tgz: package/lib-esm/Header.js <==
// eslint-disable-next-line import/no-namespace
import styled, { css } from 'styled-components';
import { get } from './constants';
import sx from './sx';
const Header = styled.div.withConfig({
  displayName: "Header",
  componentId: "sc-11fu6rh-0"
})(["z-index:32;display:flex;padding:", ";font-size:", ";line-height:", ";color:", ";background-color:", ";align-items:center;flex-wrap:nowrap;", ";"], get('space.3'), get('fontSizes.1'), get('lineHeights.default'), get('colors.header.text'), get('colors.header.bg'), sx);
const HeaderItem = styled.div.withConfig({
  displayName: "Header__HeaderItem",
  componentId: "sc-11fu6rh-1"
})(["display:flex;margin-right:", ";align-self:stretch;align-items:center;flex-wrap:nowrap;", ";", ";"], get('space.3'), ({
  full
}) => full && css(["flex:auto;"]), sx);
HeaderItem.displayName = 'Header.Item';
const HeaderLink = styled.a.attrs(({
  to
}) => {
  const isReactRouter = typeof to === 'string';

  if (isReactRouter) {
    // according to their docs, NavLink supports aria-current:
    // https://reacttraining.com/react-router/web/api/NavLink/aria-current-string
    return {
      'aria-current': 'page'
    };
  } else {
    return {};
  }
}).withConfig({
  displayName: "Header__HeaderLink",
  componentId: "sc-11fu6rh-2"
})(["font-weight:", ";color:", ";white-space:nowrap;cursor:pointer;text-decoration:none;display:flex;align-items:center;&:hover,&:focus{color:", ";}", ";"], get('fontWeights.bold'), get('colors.header.logo'), get('colors.header.text'), sx);
HeaderLink.displayName = 'Header.Link';
export default Object.assign(Header, {
  Link: HeaderLink,
  Item: HeaderItem
});

==> primer-react-34.1.2.tgz: package/lib-esm/Header.js <==
// eslint-disable-next-line import/no-namespace
import styled, { css } from 'styled-components';
import { get } from './constants';
import sx from './sx';
const Header = styled.div.withConfig({
  displayName: "Header",
  componentId: "sc-wo8nl4-0"
})(["z-index:32;display:flex;padding:", ";font-size:", ";line-height:", ";color:", ";background-color:", ";align-items:center;flex-wrap:nowrap;", ";"], get('space.3'), get('fontSizes.1'), get('lineHeights.default'), get('colors.header.text'), get('colors.header.bg'), sx);
const HeaderItem = styled.div.withConfig({
  displayName: "Header__HeaderItem",
  componentId: "sc-wo8nl4-1"
})(["display:flex;margin-right:", ";align-self:stretch;align-items:center;flex-wrap:nowrap;", ";", ";"], get('space.3'), ({
  full
}) => full && css(["flex:auto;"]), sx);
HeaderItem.displayName = 'Header.Item';
const HeaderLink = styled.a.attrs(({
  to
}) => {
  const isReactRouter = typeof to === 'string';

  if (isReactRouter) {
    // according to their docs, NavLink supports aria-current:
    // https://reacttraining.com/react-router/web/api/NavLink/aria-current-string
    return {
      'aria-current': 'page'
    };
  } else {
    return {};
  }
}).withConfig({
  displayName: "Header__HeaderLink",
  componentId: "sc-wo8nl4-2"
})(["font-weight:", ";color:", ";white-space:nowrap;cursor:pointer;text-decoration:none;display:flex;align-items:center;&:hover,&:focus{color:", ";}", ";"], get('fontWeights.bold'), get('colors.header.logo'), get('colors.header.text'), sx);
HeaderLink.displayName = 'Header.Link';
export default Object.assign(Header, {
  Link: HeaderLink,
  Item: HeaderItem
});
